@@ -16,7 +16,7 @@ app.command()(mod.main)
 def test_1():
     result = runner.invoke(app, ["Camila"])
     assert result.exit_code != 0
-    assert "Missing option '--lastname'." in result.output
+    assert "Missing option '--lastname'" in result.output
 
 
 def test_option_lastname():
