@@ -45,40 +45,23 @@ def test_params():
 def test_invalid_id():
     result = runner.invoke(app, ["1002"])
     assert result.exit_code != 0
-    # TODO: when deprecating Click 7, remove second option
     assert (
-        (
-            "Invalid value for 'ID': 1002 is not in the range 0<=x<=1000."
-            in result.output
-        )
-        or "Invalid value for 'ID': 1002 is not in the valid range of 0 to 1000."
-        in result.output
+        "Invalid value for 'ID': 1002 is not in the range 0<=x<=1000." in result.output
     )
 
 
 def test_invalid_age():
     result = runner.invoke(app, ["5", "--age", "15"])
     assert result.exit_code != 0
-    # TODO: when deprecating Click 7, remove second option
-
-    assert (
-        "Invalid value for '--age': 15 is not in the range x>=18" in result.output
-        or "Invalid value for '--age': 15 is smaller than the minimum valid value 18."
-        in result.output
-    )
+    assert "Invalid value for '--age'" in result.output
+    assert "15 is not in the range x>=18" in result.output
 
 
 def test_invalid_score():
     result = runner.invoke(app, ["5", "--age", "20", "--score", "100.5"])
     assert result.exit_code != 0
-    # TODO: when deprecating Click 7, remove second option
-
-    assert (
-        "Invalid value for '--score': 100.5 is not in the range x<=100."
-        in result.output
-        or "Invalid value for '--score': 100.5 is bigger than the maximum valid value"
-        in result.output
-    )
+    assert "Invalid value for '--score'" in result.output
+    assert "100.5 is not in the range x<=100." in result.output
 
 
 def test_negative_score():
@@ -92,8 +75,7 @@ def test_negative_score():
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
